<?php
/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

namespace common\helpers;

class Ajax
{
    const RESPONSE_TYPE_ERROR = 'error';
    const RESPONSE_TYPE_SUCCESS = 'success';

    public static function responseSuccess(string $message, array $datas = []): array
    {
        return self::response(self::RESPONSE_TYPE_SUCCESS, $message, $datas);
    }

    public static function responseError(string $message, array $datas = []): array
    {
        return self::response(self::RESPONSE_TYPE_ERROR, $message, $datas);
    }

    private static function response(string $responseType, string $message, array $datas = []): array
    {
        \Yii::$app->response->format = \yii\web\Response::FORMAT_JSON;

        return [
            'return' => $responseType,
            'alert' => [
                'type' => self::getAlertClass($responseType),
                'message' => $message
            ],
            'datas' => $datas
        ];
    }

    private static function getAlertClass(string $responseType)
    {
        $class = '';
        if($responseType == self::RESPONSE_TYPE_SUCCESS) {
            $class = 'success';
        }
        elseif($responseType == self::RESPONSE_TYPE_ERROR) {
            $class = 'danger';
        }

        return $class;
    }
}