<?php
/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use domain\User\User\User;
use domain\User\User\UserModule;

function version(string $date, array $featuresMaintenanceArray, array $featuresMaintenanceAdminArray, User $userCurrent) {
    release_date($date);
    features($featuresMaintenanceArray[0] ?? [], $featuresMaintenanceAdminArray[0] ?? [], $userCurrent);
    maintenance($featuresMaintenanceArray[1] ?? [], $featuresMaintenanceAdminArray[1] ?? [], $userCurrent);
}

function release_date(string $date) {
    $html = '<div class="block block-release-date">';
    $html .= '<h4><span class="glyphicon glyphicon-calendar"></span>  Date de sortie</h4>';
    $html .= '<ul><li>'.$date.'</li></ul>';
    $html .= '</div>';
    echo $html;
}

function features(array $featuresArray, array $featuresAdminArray, User $userCurrent) {
    $userModule = UserModule::getInstance();
    $isGrantedAsUserCurrent = $userModule->getAuthorizationChecker()->isGrantedAsAdministrator($userCurrent);
    if(count($featuresArray) > 0 || (count($featuresAdminArray) > 0 && $isGrantedAsUserCurrent)) {
        $html = '<div class="block block-features">';
        $html .= '<h4><span class="glyphicon glyphicon-flash"></span> Évolutions</h4>';
        $html .= '<ul>';
        foreach($featuresArray as $feature) {
            $html .= '<li>'.$feature.'</li>';
        }
        if($isGrantedAsUserCurrent) {
            foreach($featuresAdminArray as $feature) {
                $html .= '<li class="admin">'.$feature.'</li>';
            }
        }
        $html .= '</ul>';
        $html .= '</div>';
        echo $html;
    }
}

function maintenance(array $maintenanceArray, array $maintenanceAdminArray, User $userCurrent) {
    $userModule = UserModule::getInstance();
    if(count($maintenanceArray) > 0 || count($maintenanceAdminArray) > 0) {
        $html = '<div class="block block-maintenance">';
        $html .= '<h4><span class="glyphicon glyphicon-wrench"></span> Maintenance</h4>';
        $html .= '<ul>';
        foreach($maintenanceArray as $maintenance) {
            $html .= '<li>'.$maintenance.'</li>';
        }
        if($userModule->getAuthorizationChecker()->isGrantedAsAdministrator($userCurrent)) {
            foreach ($maintenanceAdminArray as $maintenance) {
                $html .= '<li class="admin">' . $maintenance . '</li>';
            }
        }
        $html .= '</ul>';
        $html .= '</div>';
        echo $html;
    }
}