<?php
/**
 * Copyright Guillaume Bourgeois (2018)
 *
 * contact@souke.fr
 *
 * Ce logiciel est un programme informatique servant à aider les producteurs
 * à distribuer leur production en circuits courts.
 *
 * Ce logiciel est régi par la licence CeCILL soumise au droit français et
 * respectant les principes de diffusion des logiciels libres. Vous pouvez
 * utiliser, modifier et/ou redistribuer ce programme sous les conditions
 * de la licence CeCILL telle que diffusée par le CEA, le CNRS et l'INRIA
 * sur le site "http://www.cecill.info".
 *
 * En contrepartie de l'accessibilité au code source et des droits de copie,
 * de modification et de redistribution accordés par cette licence, il n'est
 * offert aux utilisateurs qu'une garantie limitée.  Pour les mêmes raisons,
 * seule une responsabilité restreinte pèse sur l'auteur du programme,  le
 * titulaire des droits patrimoniaux et les concédants successifs.
 *
 * A cet égard  l'attention de l'utilisateur est attirée sur les risques
 * associés au chargement,  à l'utilisation,  à la modification et/ou au
 * développement et à la reproduction du logiciel par l'utilisateur étant
 * donné sa spécificité de logiciel libre, qui peut le rendre complexe à
 * manipuler et qui le réserve donc à des développeurs et des professionnels
 * avertis possédant  des  connaissances  informatiques approfondies.  Les
 * utilisateurs sont donc invités à charger  et  tester  l'adéquation  du
 * logiciel à leurs besoins dans des conditions permettant d'assurer la
 * sécurité de leurs systèmes et ou de leurs données et, plus généralement,
 * à l'utiliser et l'exploiter dans les mêmes conditions de sécurité.
 *
 * Le fait que vous puissiez accéder à cet en-tête signifie que vous avez
 * pris connaissance de la licence CeCILL, et que vous en avez accepté les
 * termes.
 */

use domain\Feature\Feature\Feature;
use yii\helpers\Html;

$producerModule = $this->getProducerModule();
$featureChecker = $this->getFeatureModule()->getChecker();

$this->setTitle('Fonctionnalités, services & tarifs');
$this->setMeta('description', "Découvrez les fonctionnalités du logiciel, les services proposés et les tarifs pour l’hébergement de votre circuit court sur Souke.");

?>
    <div class="site-service">
        <div class="content-text">
            <div id="row-functionalities-rates">
                <div class="panel panel-primary panel-padding-large panel-margin-bottom" id="block-functionnalities">
                    <div class="panel-heading">
                        <h2 class="panel-title">
                            <span class="the-title">Fonctionnalités</span>
                        </h2>
                    </div>
                    <div class="panel-body">
                        <div class="row">
                            <?= block_feature('shop', "Une boutique dédiée accessible à vos clients pour leur présenter votre activité et gérer vos prises de commandes"); ?>
                            <?= block_feature("gear", "Une administration complète et intuitive pour gérer votre activité de producteur"); ?>
                        </div>
                        <div class="row">
                            <?= block_feature("calendar3", "Planification des jours de distributions"); ?>
                            <?= block_feature("download", "Récapitulatif des commandes par jour de distribution (PDF et CSV)<br />Génération d'étiquettes simple (PDF)<br />Génération d'étiquettes avec format spécifique (PDF) *"); ?>
                        </div>
                        <div class="row">
                            <?= block_feature("basket", "Gestion des produits, catégories et prix spécifiques<br />Gestion des accessoires produits *"); ?>
                            <?php $featureSharedPointSaleDescription = '';
                            if($featureChecker->isEnabled(Feature::ALIAS_SHARED_POINT_SALE)):
                                $featureSharedPointSaleDescription .= "<br />Partage de points de vente entre plusieurs producteurs pour des distributions communes";
                            endif; ?>
                            <?= block_feature("geo-alt", "Gestion des points de vente ".$featureSharedPointSaleDescription); ?>
                        </div>
                        <div class="row">
                            <?= block_feature("arrow-repeat", "Gestion des abonnements pour les commandes récurrentes"); ?>
                            <?= block_feature("people", "Gestion des clients"); ?>
                        </div>
                        <div class="row">
                            <?= block_feature("piggy-bank", "Système de cagnotte permettant la comptabilisation des paiements"); ?>
                            <?= block_feature("credit-card", "Paiement en ligne via la plateforme <strong>Stripe</strong> pour le paiement des commandes ou l'alimentation des cagnottes *"); ?>
                        </div>
                        <div class="row">
                            <?= block_feature("megaphone", "Envoi d'emails en masse<br />Emails automatiques programmables pour les prises de commande *"); ?>
                            <?= block_feature("file-earmark-text", "Génération de bons de livraison, factures & devis"); ?>
                        </div>
                        <div class="row">
                            <?= block_feature("graph-up", "Statistiques et rapports de vente"); ?>
                            <?= block_feature("cloud-arrow-up", "Exports vers les logiciels <strong>Evoliz</strong> (comptabilité) et <strong>SumUp</strong> (caisse) *"); ?>
                        </div>

                        <p>
                            * <a href="#modules">Modules payants</a>
                        </p>
                    </div>
                </div>

                <div class="panel panel-primary panel-padding-large panel-margin-bottom" id="block-services">
                    <div class="panel-heading">
                        <h2 class="panel-title">
                            <span class="the-title">Services</span>
                        </h2>
                    </div>
                    <div class="panel-body">
                        <div class="row">
                            <div class="col-md-6">
                                <div class="panel panel-default">
                                    <div class="panel-body">
                                        <h3>Formation</h3>
                                        <p>Au moment du lancement de votre circuit court sur Souke,
                                            j'assure votre formation à l'utilisation du logiciel en prenant en compte
                                            tous les aspects spécifiques de votre activité de producteur.</p>
                                    </div>
                                </div>
                                <div class="panel panel-default">
                                    <div class="panel-body">
                                        <h3>Support</h3>
                                        <p>Une fois que vous êtes lancé sur le logiciel, je reste disponible pour répondre
                                            à toutes vos questions et problèmatiques par téléphone, email ou ticket.
                                            <?php if($featureChecker->isEnabled(Feature::ALIAS_SHOP_SUPPORT)): ?>
                                                J'assure également le support pour vos clients par email s'ils
                                                rencontrent un problème sur votre boutique.
                                            <?php endif; ?>
                                        </p>
                                    </div>
                                </div>
                                <div class="panel panel-default">
                                    <div class="panel-body">
                                        <h3>Maintenance</h3>
                                        <p>Si une anomalie apparait sur le logiciel, j'interviens au plus vite pour
                                            la corriger. Par ailleurs, chaque problème est analysé et résolu en profondeur pour en
                                            comprendre l'origine et éviter qu'il ne se reproduise.</p>
                                    </div>
                                </div>
                            </div>
                            <div class="col-md-6">
                                <div class="panel panel-default">
                                    <div class="panel-body">
                                        <h3>Fonctionnalités</h3>
                                        <p>Des évolutions sont régulièrement ajoutées au logiciel. Ces évolutions sont
                                            développées en fonction des besoins les plus communs et prioritaires des producteurs
                                            ainsi que du budget disponible.<br />
                                            Pour répondre à certains besoins spécifiques, des
                                            <a href="#modules">modules payants</a> sont disponibles en complément de la
                                            tarification de base.<br />
                                            Enfin, si vous avez besoin d'une fonctionnalité non couverte
                                            par le logiciel, vous pouvez également la financer directement en me demandant
                                            <a href="<?= \Yii::$app->urlManager->createUrl(['site/contact']) ?>">un devis</a>.
                                        </p>
                                    </div>
                                </div>
                                <div class="panel panel-default">
                                    <div class="panel-body">
                                        <h3>Hébergement</h3>
                                        <p>La plateforme est hébergée en France par la société
                                            <a href="https://www.alwaysdata.com/">Alwaysdata</a>.<br />
                                            Des sauvegardes sont réalisées quotidiennement et conservées 30 jours.
                                        </p>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="panel panel-primary panel-padding-large panel-margin-bottom" id="block-rates">
                    <div class="panel-heading">
                        <h2 class="panel-title">
                            <span class="glyphicon glyphicon-euro"></span>
                            <span class="the-title">Tarifs</span>
                        </h2>
                    </div>
                    <div class="panel-body">
                        <?= $this->render('_prices_producer', [
                                'dataProviderPrices' => $dataProviderPrices,
                                'paidFeaturesArray' => $paidFeaturesArray
                        ]); ?>
                    </div>
                </div>

                <div class="panel panel-primary" id="panel-go-further">
                    <div class="panel-heading">
                        <h2 class="panel-title">
                            <span class="glyphicon glyphicon-plus"></span>
                            <span class="the-title">Pour aller plus loin</span>
                        </h2>
                    </div>
                    <div class="panel-body">
                        <p class="text-center">
                            <?= $this->render('_button_producer_signup'); ?>
                            <?php if (Yii::$app->user->isGuest): ?>
                            <a class="btn btn-secondary"
                               href="<?= $this->getUrlManagerFrontend()->createUrl(['site/producer', 'id' => 32]); ?>">
                                <i class="bi bi-check2-square"></i> Je teste le logiciel
                            </a>
                            <?php endif; ?>
                            <a class="btn btn-secondary" href="<?= \Yii::$app->parameterBag->get('appointmentUrl'); ?>"
                               target="_blank">
                                <i class="bi bi-eye"></i> Je demande une démo
                            </a>
                            <a class="btn btn-secondary"
                               href="<?= $this->getUrlManagerFrontend()->createUrl(['site/about']); ?>">
                                <i class="bi bi-info-circle"></i> À propos
                            </a>
                            <a class="btn btn-secondary"
                               href="<?= $this->getUrlManagerFrontend()->createUrl(['site/contact']); ?>">
                                <i class="bi bi-envelope"></i> Contact
                            </a>
                        </p>
                    </div>
                </div>

            </div>
            <div class="clr"></div>
        </div>
    </div>

<?php

function block_feature($icon, $description)
{
    return '<div class="block col-md-6">
                    <i class="bi bi-' . $icon . '"></i>
                    <p>' . $description . '</p>
                </div>';
}

?>